@@ -1,48 +1,13 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_DOWNLOAD_CHOKE_QUEUE_H
 #define LIBTORRENT_DOWNLOAD_CHOKE_QUEUE_H
 
-#include <torrent/common.h>
-
-#include <list>
-#include <vector>
-#include <inttypes.h>
+#include <cinttypes>
 #include <functional>
+#include <list>
+#include <utility>
+#include <vector>
+
+#include <torrent/common.h>
 #include <torrent/download/group_entry.h>
 
 namespace torrent {
@@ -66,53 +31,49 @@ struct group_stats {
 
 class LIBTORRENT_EXPORT choke_queue {
 public:
-  typedef std::function<void (int)>                         slot_unchoke;
-  typedef std::function<int ()>                             slot_can_unchoke;
-  typedef std::function<bool (PeerConnectionBase*, bool)>   slot_connection;
+  using slot_unchoke     = std::function<void(int)>;
+  using slot_can_unchoke = std::function<int()>;
+  using slot_connection  = std::function<bool(PeerConnectionBase*, bool)>;
 
-  typedef std::vector<weighted_connection>                       container_type;
-  typedef container_type::value_type                             value_type;
-  typedef container_type::iterator                               iterator;
+  using container_type = std::vector<weighted_connection>;
+  using value_type     = container_type::value_type;
+  using iterator       = container_type::iterator;
 
-  typedef std::pair<uint32_t, iterator>                          target_type;
+  using target_type = std::pair<uint32_t, iterator>;
 
-  typedef std::vector<group_entry*>                              group_container_type;
+  using group_container_type = std::vector<group_entry*>;
 
-  typedef void (*slot_weight)(iterator first, iterator last);
+  using slot_weight = void (*)(iterator first, iterator last);
 
-  static const int flag_unchoke_all_new = 0x1;
+  static constexpr int flag_unchoke_all_new = 0x1;
 
-  static const uint32_t order_base = (1 << 30);
-  static const uint32_t order_max_size = 4;
-  static const uint32_t weight_size_bytes = order_max_size * sizeof(uint32_t);
+  static constexpr uint32_t order_base = (1 << 30);
+  static constexpr uint32_t order_max_size = 4;
+  static constexpr uint32_t weight_size_bytes = order_max_size * sizeof(uint32_t);
 
-  static const uint32_t unlimited = ~uint32_t();
+  static constexpr uint32_t unlimited = ~uint32_t();
 
   struct heuristics_type {
     slot_weight         slot_choke_weight;
     slot_weight         slot_unchoke_weight;
-    
+
     uint32_t            choke_weight[order_max_size];
     uint32_t            unchoke_weight[order_max_size];
   };
 
    enum heuristics_enum {
     HEURISTICS_UPLOAD_LEECH,
-    HEURISTICS_UPLOAD_LEECH_DUMMY,
+    HEURISTICS_UPLOAD_SEED,
+    HEURISTICS_UPLOAD_LEECH_EXPERIMENTAL,
     HEURISTICS_DOWNLOAD_LEECH,
-    HEURISTICS_DOWNLOAD_LEECH_DUMMY,
     HEURISTICS_MAX_SIZE
   };
 
   choke_queue(int flags = 0) :
-    m_flags(flags),
-    m_heuristics(HEURISTICS_MAX_SIZE),
-    m_maxUnchoked(unlimited),
-    m_currently_queued(0),
-    m_currently_unchoked(0),
-    m_slotConnection(NULL) {}
+    m_flags(flags)
+    {}
   ~choke_queue();
-  
+
   bool                is_full() const                         { return !is_unlimited() && size_unchoked() >= m_maxUnchoked; }
   bool                is_unlimited() const                    { return m_maxUnchoked == unlimited; }
 
@@ -144,9 +105,9 @@ public:
   heuristics_enum     heuristics() const                       { return m_heuristics; }
   void                set_heuristics(heuristics_enum hs)       { m_heuristics = hs; }
 
-  void                set_slot_unchoke(slot_unchoke s)         { m_slotUnchoke = s; }
-  void                set_slot_can_unchoke(slot_can_unchoke s) { m_slotCanUnchoke = s; }
-  void                set_slot_connection(slot_connection s)   { m_slotConnection = s; }
+  void                set_slot_unchoke(slot_unchoke s)         { m_slotUnchoke = std::move(s); }
+  void                set_slot_can_unchoke(slot_can_unchoke s) { m_slotCanUnchoke = std::move(s); }
+  void                set_slot_connection(slot_connection s)   { m_slotConnection = std::move(s); }
 
   // TODO: Consider putting this in queue_group.
   group_container_type& group_container()                      { return m_group_container; }
@@ -155,6 +116,9 @@ public:
   void                modify_currently_unchoked(int value)     { m_currently_unchoked += value; }
 
 private:
+  choke_queue(const choke_queue&) = delete;
+  choke_queue& operator=(const choke_queue&) = delete;
+
   group_stats         prepare_weights(group_stats gs);
   group_stats         retrieve_connections(group_stats gs, container_type* queued, container_type* unchoked);
   void                rebuild_containers(container_type* queued, container_type* unchoked);
@@ -168,12 +132,12 @@ private:
   static heuristics_type m_heuristics_list[HEURISTICS_MAX_SIZE];
 
   int                 m_flags;
-  heuristics_enum     m_heuristics;
+  heuristics_enum     m_heuristics{HEURISTICS_MAX_SIZE};
 
-  uint32_t            m_maxUnchoked;
+  uint32_t            m_maxUnchoked{unlimited};
 
-  uint32_t            m_currently_queued;
-  uint32_t            m_currently_unchoked;
+  uint32_t            m_currently_queued{0};
+  uint32_t            m_currently_unchoked{0};
 
   slot_unchoke        m_slotUnchoke;
   slot_can_unchoke    m_slotCanUnchoke;
