@@ -49,41 +49,41 @@ namespace torrent {
 
 class LIBTORRENT_EXPORT Object {
 public:
-  typedef int64_t                           value_type;
-  typedef std::string                       string_type;
-  typedef std::vector<Object>               list_type;
-  typedef std::map<std::string, Object>     map_type;
-  typedef map_type*                         map_ptr_type;
-  typedef map_type::key_type                key_type;
-  typedef std::pair<std::string, Object*>   dict_key_type;
+  using value_type    = int64_t;
+  using string_type   = std::string;
+  using list_type     = std::vector<Object>;
+  using map_type      = std::map<std::string, Object>;
+  using map_ptr_type  = map_type*;
+  using key_type      = map_type::key_type;
+  using dict_key_type = std::pair<std::string, Object*>;
 
-  typedef list_type::iterator               list_iterator;
-  typedef list_type::const_iterator         list_const_iterator;
-  typedef list_type::reverse_iterator       list_reverse_iterator;
-  typedef list_type::const_reverse_iterator list_const_reverse_iterator;
+  using list_iterator               = list_type::iterator;
+  using list_const_iterator         = list_type::const_iterator;
+  using list_reverse_iterator       = list_type::reverse_iterator;
+  using list_const_reverse_iterator = list_type::const_reverse_iterator;
 
-  typedef map_type::iterator                map_iterator;
-  typedef map_type::const_iterator          map_const_iterator;
-  typedef map_type::reverse_iterator        map_reverse_iterator;
-  typedef map_type::const_reverse_iterator  map_const_reverse_iterator;
+  using map_iterator               = map_type::iterator;
+  using map_const_iterator         = map_type::const_iterator;
+  using map_reverse_iterator       = map_type::reverse_iterator;
+  using map_const_reverse_iterator = map_type::const_reverse_iterator;
 
-  typedef std::pair<map_iterator, bool>     map_insert_type;
+  using map_insert_type = std::pair<map_iterator, bool>;
 
   // Flags in the range of 0xffff0000 may be set by the user, however
   // 0x00ff0000 are reserved for keywords defined by libtorrent.
-  static const uint32_t mask_type     = 0xff;
-  static const uint32_t mask_flags    = ~mask_type;
-  static const uint32_t mask_internal = 0xffff;
-  static const uint32_t mask_public   = ~mask_internal;
+  static constexpr uint32_t mask_type     = 0xff;
+  static constexpr uint32_t mask_flags    = ~mask_type;
+  static constexpr uint32_t mask_internal = 0xffff;
+  static constexpr uint32_t mask_public   = ~mask_internal;
 
-  static const uint32_t flag_unordered    = 0x100;    // bencode dictionary was not sorted
-  static const uint32_t flag_static_data  = 0x010000;  // Object does not change across sessions.
-  static const uint32_t flag_session_data = 0x020000;  // Object changes between sessions.
-  static const uint32_t flag_function     = 0x040000;  // A function object.
-  static const uint32_t flag_function_q1  = 0x080000;  // A quoted function object.
-  static const uint32_t flag_function_q2  = 0x100000;  // A double-quoted function object.
+  static constexpr uint32_t flag_unordered    = 0x100;    // bencode dictionary was not sorted
+  static constexpr uint32_t flag_static_data  = 0x010000;  // Object does not change across sessions.
+  static constexpr uint32_t flag_session_data = 0x020000;  // Object changes between sessions.
+  static constexpr uint32_t flag_function     = 0x040000;  // A function object.
+  static constexpr uint32_t flag_function_q1  = 0x080000;  // A quoted function object.
+  static constexpr uint32_t flag_function_q2  = 0x100000;  // A double-quoted function object.
 
-  static const uint32_t mask_function     = 0x1C0000;  // Mask for function objects.
+  static constexpr uint32_t mask_function     = 0x1C0000;  // Mask for function objects.
 
   enum type_type {
     TYPE_NONE,
@@ -98,7 +98,6 @@ public:
     TYPE_DICT_KEY
   };
 
-  Object()                     : m_flags(TYPE_NONE) {}
   Object(const value_type v)   : m_flags(TYPE_VALUE) { new (&_value()) value_type(v); }
   Object(const char* s)        : m_flags(TYPE_STRING) { new (&_string()) string_type(s); }
   Object(const string_type& s) : m_flags(TYPE_STRING) { new (&_string()) string_type(s); }
@@ -106,9 +105,11 @@ public:
   Object(const raw_string& r)  : m_flags(TYPE_RAW_STRING) { new (&_raw_string()) raw_string(r); }
   Object(const raw_list& r)    : m_flags(TYPE_RAW_LIST) { new (&_raw_list()) raw_list(r); }
   Object(const raw_map& r)     : m_flags(TYPE_RAW_MAP) { new (&_raw_map()) raw_map(r); }
-  Object(const Object& b);
 
+  Object() {}
   ~Object() { clear(); }
+  Object(const Object& b);
+  Object& operator=(const Object& b);
 
   // TODO: Move this out of the class namespace, call them
   // make_object_. 
@@ -134,7 +135,7 @@ public:
   // cases where we pass constant rvalues.
   void                clear();
 
-  type_type           type() const                            { return (type_type)(m_flags & mask_type); }
+  type_type           type() const                            { return static_cast<type_type>(m_flags & mask_type); }
   uint32_t            flags() const                           { return m_flags & mask_flags; }
 
   void                set_flags(uint32_t f)                   { m_flags |= f & mask_public; }
@@ -231,9 +232,9 @@ public:
   Object&             insert_back(const Object& b)                   { check_throw(TYPE_LIST); return *_list().insert(_list().end(), b); }
 
   // Copy and merge operations:
-  Object&             move(Object& b);
-  Object&             swap(Object& b);
-  Object&             swap_same_type(Object& b);
+  Object&             move(Object& b) noexcept;
+  Object&             swap(Object& b) noexcept;
+  Object&             swap_same_type(Object& b) noexcept;
 
   // Only map entries are merged.
   Object&             merge_move(Object& object, uint32_t maxDepth = ~uint32_t());
@@ -241,18 +242,16 @@ public:
                                  uint32_t skip_mask = flag_static_data,
                                  uint32_t maxDepth = ~uint32_t());
 
-  Object&             operator = (const Object& b);
-
   // Internal:
-  void                swap_same_type(Object& left, Object& right);
+  void                swap_same_type(Object& left, Object& right) noexcept;
 
  private:
-  inline bool         check(map_type::const_iterator itr, type_type t) const { return itr != _map().end() && itr->second.type() == t; }
-  inline void         check_throw(type_type t) const                         { if (t != type()) throw bencode_error("Wrong object type."); }
+  bool                check(map_type::const_iterator itr, type_type t) const { return itr != _map().end() && itr->second.type() == t; }
+  void                check_throw(type_type t) const                         { if (t != type()) throw bencode_error("Wrong object type."); }
 
   template <typename T> void check_value_throw(const char* err_msg) const;
 
-  uint32_t            m_flags;
+  uint32_t            m_flags{TYPE_NONE};
 
 #ifndef HAVE_STDCXX_0X
   value_type&         _value()             { return t_value; }
@@ -344,8 +343,8 @@ public:
 };
 
 inline
-Object::Object(const Object& b) {
-  m_flags = b.m_flags & (mask_type | mask_public);
+Object::Object(const Object& b) :
+    m_flags(b.m_flags & (mask_type | mask_public)) {
 
   switch (type()) {
   case TYPE_NONE:
@@ -462,7 +461,7 @@ Object::clear() {
 }
 
 inline void
-Object::swap_same_type(Object& left, Object& right) {
+Object::swap_same_type(Object& left, Object& right) noexcept {
   std::swap(left.m_flags, right.m_flags);
 
   switch (left.type()) {
@@ -475,7 +474,7 @@ Object::swap_same_type(Object& left, Object& right) {
   }
 }
 
-inline void swap(Object& left, Object& right) { left.swap(right); }
+inline void swap(Object& left, Object& right) noexcept { left.swap(right); }
 
 inline bool
 object_equal(const Object& left, const Object& right) {
